@@ -21,6 +21,10 @@ def copy_results_to_external_target(source_list=None, target=None):
                     pass
         except Exception as e:
             etld_lib_functions.logger.error(f"Exception: {e}")
+            etld_lib_functions.logger.error(f"Error distributing files.  ")
+            etld_lib_functions.logger.error(f"etld_lib_config_settings.yaml [named]_export_dir "
+                                            f"directory accessibility issue: {target}")
             exit(1)
     else:
-        etld_lib_functions.logger.info(f"etld_lib_config_settings.yaml [named]_export_dir directory does not exist: {target}")
+        etld_lib_functions.logger.error(f"etld_lib_config_settings.yaml [named]_export_dir directory does not exist: {target}")
+        exit(1)
